Changelog
=========

.. currentmodule:: marnadi

Release 0.2.7
-------------

- Fix #14: Fixed cookies with international locales

Release 0.2.6
-------------

- Fix: Fixed HttpError, responses due to not supported and not allowed methods
